@@ -2,7 +2,7 @@
 import datetime
 from os import environ
 
-useColor = environ.get("FLASK_LOG_COLOR") if environ.get("FLASK_LOG_COLOR") is not None else True
+useColor = environ.get("FLASK_LOG_COLOR") == 'True' if environ.get("FLASK_LOG_COLOR") is not None else True
 dateFormat = environ.get("FLASK_LOG_DATE_FORMAT") if environ.get("FLASK_LOG_DATE_FORMAT") is not None else "%d/%b/%Y %H:%M:%S"
 
 class bcolors:
@@ -38,4 +38,6 @@ class log:
         print (bcolors.WARNING,self.main,self.timestamp,'[**Error**]',self.string,bcolors.ENDC) if useColor else print(self.main,self.timestamp,'[**Error**]',self.string)
 
 def get_current_time():
-    return datetime.datetime.now().strftime("["+dateFormat+"]")
\ No newline at end of file
+    return datetime.datetime.now().strftime("["+dateFormat+"]")
+
+log('Hello World').success()
\ No newline at end of file
